0.9.9 API documentation: GLM_EXT_scalar_relational

| 0.9.9 API documentation

- Main Page
- Modules
- Files

GLM_EXT_scalar_relational
Stable extensions

Exposes comparison functions for scalar types that take a user defined epsilon values. More...

Exposes comparison functions for scalar types that take a user defined epsilon values.

Include <glm/ext/scalar_relational.hpp> to use the features of this extension.

See also
  core_vector_relational
  GLM_EXT_vector_relational
  GLM_EXT_matrix_relational